helga-oneliner
==================

A helga plugin with a large amount of canned responses for a variety of regular expressions. For the
full list, see the `source code <https://github.com/shaunduncan/helga-oneliner/blob/master/helga_oneliner.py>`
for this plugin.


License
-------

Copyright (c) 2015 Shaun Duncan

Licensed under an `MIT`_ license.

.. _`MIT`: https://github.com/shaunduncan/helga-oneliner/blob/master/LICENSE
